#!/usr/bin/perl

# Wcal updater from 2.0 to 2.1
# by Joel Savignon

use strict;

my $force = 0;
if ($ARGV[0] eq "-f")
{
    $force = 1;
}

my $wcalddir = "/usr/local/bin";
print "Wcal updater\n";
print "Please select the location of your wcald file\n";
print "($wcalddir) : ";
my $dir = <STDIN>;
chomp($dir);
if ($dir)
{
    $wcalddir = $dir;
}

if (!-e "$wcalddir/wcald")
{
    print "\n*** No $wcalddir/wcald file! ***\n";
    print "Update canceled\n";
    exit 1;
}

my ($wcalddev,$wcaldino,$wcaldmode,$wcaldnlink,$wcalduid,$wcaldgid) = stat("$wcalddir/wcald");
my $line;
if (!open(WCALD, "$wcalddir/wcald"))
{
    print "\n*** Unable to open $wcalddir/wcald file! ***\n";
    print "Update canceled\n";
    exit 2;
}
my $wcaldvers;
my $wcaldconfdir;
my $wcaldhttpdir;
my $wcalddbdir;
my $perlcmd;
$wcaldmode = $wcaldmode & 0777;

print "wcal uid : $wcalduid\n";
print "wcal gid : $wcaldgid\n";
printf "wcal mod : %o\n", $wcaldmode;

$perlcmd = <WCALD>;
print "perl cmd : $perlcmd";

while ($line = <WCALD>)
{
    if ($line =~ /^\#\s*Wcal\s*([\d\.]+)\s*/ && !$wcaldvers)
    {
	$wcaldvers = $1+0;
	print "wcal ver : $wcaldvers\n";
    }
    if ($line =~ /^\$::VERSION\s*=\s*\"([^\"]*)/)
    {
	$wcaldvers = $1+0;
	print "wcal ver : $wcaldvers\n";
    }
    elsif ($line =~ /^\$::CONF_FILE\s*=\s*\'([^\']*)\/wcal.conf/)
    {
	$wcaldconfdir = $1;
	print "conf dir : $wcaldconfdir\n";
    }
    elsif ($line =~ /^\$::DIRECTORY\s*=\s*\'([^\']*)/)
    {
	$wcaldhttpdir = $1;
	print "http dir : $wcaldhttpdir\n";
    }
    elsif ($line =~ /^\$::DB_DIR\s*=\s*\'([^\']*)/)
    {
	$wcalddbdir = $1;
	print "data dir : $wcalddbdir\n";
    }
}
close(WCALD);

if (!$force && $wcaldvers < 2.0)
{
    print "\n*** Current version of wcal must be at least 2.0 ***\n";
    print "Update canceled\n";
    exit 3;
}

print ("Copying wcald\n");
rename("$wcalddir/wcald", "$wcalddir/wcald.2.0");
open(WCALD2, ">$wcalddir/wcald");
open(WCALD, "wcald.in");
$line = <WCALD>;
print WCALD2 $perlcmd;
while ($line = <WCALD>)
{
    if ($line =~ /^\$::CONF_FILE\s*=/)
    {
	print WCALD2 "\$::CONF_FILE = '$wcaldconfdir/wcal.conf';\n";
    }
    elsif ($line =~ /^\$::MSG_FILE\s*=/)
    {
	print WCALD2 "\$::MSG_FILE = '$wcaldconfdir/wcal.msg';\n";
    }
    elsif ($line =~ /^\$::DEF_FILE\s*=/)
    {
	print WCALD2 "\$::DEF_FILE = '$wcaldconfdir/wcal.def';\n";
    }
    elsif ($line =~ /^\$::SDAYS_FILE\s*=/)
    {
	print WCALD2 "\$::SDAYS_FILE = '$wcaldconfdir/wcal.sdays';\n";
    }
    elsif ($line =~ /^\$::DIRECTORY\s*=/)
    {
	print WCALD2 "\$::DIRECTORY = '$wcaldhttpdir';\n";
    }
    elsif ($line =~ /^\$::DB_DIR\s*=/)
    {
	print WCALD2 "\$::DB_DIR = '$wcalddbdir';\n";
    }
    else
    {
	print WCALD2 $line;
    }
}
close(WCALD);
close(WCALD2);
chown($wcalduid, $wcaldgid, "$wcalddir/wcald");
chmod($wcaldmode, "$wcalddir/wcald");

print ("Copying wcal.msg\n");
($wcalddev,$wcaldino,$wcaldmode,$wcaldnlink,$wcalduid,$wcaldgid) = stat("$wcaldconfdir/wcal.msg");
system("cp wcal.msg $wcaldconfdir/wcal.msg");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/wcal.msg");
chmod($wcaldmode, "$wcaldconfdir/wcal.msg");
if (!-e "$wcaldconfdir/wcal.def")
{
    print ("Copying wcal.def\n");
    system("cp wcal.def $wcaldconfdir/wcal.def");
    chown($wcalduid, $wcaldgid, "$wcaldconfdir/wcal.def");
    chmod($wcaldmode, "$wcaldconfdir/wcal.def");
}
if (!-e "$wcaldconfdir/wcal.sdays")
{
    print ("Copying wcal.sdays\n");
    system("cp wcal.sdays $wcaldconfdir/wcal.sdays");
    chown($wcalduid, $wcaldgid, "$wcaldconfdir/wcal.sdays");
    chmod($wcaldmode, "$wcaldconfdir/wcal.sdays");
}
($wcalddev,$wcaldino,$wcaldmode,$wcaldnlink,$wcalduid,$wcaldgid) = stat("$wcaldhttpdir/images/background.jpg");
print ("Copying group1.gif\n");
system("cp images/group1.gif $wcaldhttpdir/images");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/images/group1.gif");
chmod($wcaldmode, "$wcaldconfdir/images/group1.gif");
print ("Copying group2.gif\n");
system("cp images/group2.gif $wcaldhttpdir/images");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/images/group2.gif");
chmod($wcaldmode, "$wcaldconfdir/images/group2.gif");
print ("Copying lock.gif\n");
system("cp images/lock.gif $wcaldhttpdir/images");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/images/lock.gif");
chmod($wcaldmode, "$wcaldconfdir/images/lock.gif");
print ("Copying doc files\n");
system("cp -R doc $wcaldhttpdir ; chmod -R 0750 $wcaldhttpdir/doc");

print ("\nWcal successfully updated\n");
print ("Restart wcald to make changes available\n");
